CurvedPowerLaw — pysm v3.1.dev260

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.1.dev260 »
- CurvedPowerLaw

# CurvedPowerLaw

class `pysm.` `CurvedPowerLaw`(map_I, freq_ref_I, map_pl_index, nside, spectral_curvature, freq_curve, map_Q=None, map_U=None, freq_ref_P=None, unit_I=None, unit_Q=None, unit_U=None, map_dist=None)

  Bases: `pysm.PowerLaw`

  Methods Summary

  `get_emission`(self, freqs[, weights]) | This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None)

    This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

    Parameters
      freqs: scalar or array astropy.units.Quantity

        Frequency at which the model should be evaluated, in a frequency which can be converted to GHz using astropy.units. If an array of frequencies is provided, integrate using trapz with a equal weighting, i.e. simulate a top-hat bandpass.

      weights: np.array, optional

        Array of weights describing the frequency response of the instrument, i.e. the bandpass. Weights are normalized and applied in Jy/sr.

    Returns
      outputastropy.units.Quantity

        Simulated map at the given frequency or integrated over the given bandpass. The shape of the output is (3,npix) for polarized components, (1,npix) for temperature-only components. Output is in `uK_RJ`.